@@ -1,4 +1,4 @@
-#! /usr/bin/python
+#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 """Test the classic PyGreSQL interface.
@@ -22,12 +22,12 @@ import pg  # the module under test
 
 from datetime import timedelta
 
-try:
+try:  # noinspection PyUnresolvedReferences
     long
 except NameError:  # Python >= 3.0
     long = int
 
-try:
+try:  # noinspection PyUnresolvedReferences
     unicode
 except NameError:  # Python >= 3.0
     unicode = str
@@ -66,6 +66,16 @@ class TestHasConnect(unittest.TestCase):
     def testhasPgNotSupportedError(self):
         self.assertTrue(issubclass(pg.NotSupportedError, pg.DatabaseError))
 
+    def testhasPgInvalidResultError(self):
+        self.assertTrue(issubclass(pg.InvalidResultError, pg.DataError))
+
+    def testhasPgNoResultError(self):
+        self.assertTrue(issubclass(pg.NoResultError, pg.InvalidResultError))
+
+    def testhasPgMultipleResultsError(self):
+        self.assertTrue(
+            issubclass(pg.MultipleResultsError, pg.InvalidResultError))
+
     def testhasConnect(self):
         self.assertTrue(callable(pg.connect))
 
@@ -202,6 +212,8 @@ class TestParseArray(unittest.TestCase):
         ('[-1:+1]={1,2,3}', int, [1, 2, 3]),
         ('[-3:-1]={1,2,3}', int, [1, 2, 3]),
         ('[+1:+3]={1,2,3}', int, [1, 2, 3]),
+        ('[0:2]={1,2,3}', int, [1, 2, 3]),
+        ('[7:9]={1,2,3}', int, [1, 2, 3]),
         ('[]={1,2,3}', int, ValueError),
         ('[1:]={1,2,3}', int, ValueError),
         ('[:3]={1,2,3}', int, ValueError),
@@ -1003,27 +1015,6 @@ class TestConfigFunctions(unittest.TestCase):
         self.assertIsInstance(r, bool)
         self.assertIs(r, bytea_escaped)
 
-    def testGetNamedresult(self):
-        r = pg.get_namedresult()
-        self.assertTrue(callable(r))
-        self.assertIs(r, pg._namedresult)
-
-    def testSetNamedresult(self):
-        namedresult = pg.get_namedresult()
-        try:
-            pg.set_namedresult(None)
-            r = pg.get_namedresult()
-            self.assertIsNone(r)
-            f = lambda q: q.getresult()
-            pg.set_namedresult(f)
-            r = pg.get_namedresult()
-            self.assertIs(r, f)
-            self.assertRaises(TypeError, pg.set_namedresult, 'invalid')
-        finally:
-            pg.set_namedresult(namedresult)
-        r = pg.get_namedresult()
-        self.assertIs(r, namedresult)
-
     def testGetJsondecode(self):
         r = pg.get_jsondecode()
         self.assertTrue(callable(r))
